@@ -21,7 +21,7 @@ class PdpRepo:
         self.__policiesTablePolicyTypeFieldName = policiesTablePolicyTypeFieldName
         self.__policiesKeyPrefix = policiesKeyPrefix 
         self.__policiesDdbTableResource = _DYNAMODB_RESOURCE.Table(policiesTableName)
-        self.__logger = Logger(child=True)
+        self.__logger = Logger()
 
     def savePolicy(self, policy:Policy) -> None:
         policyDict = ObjectUtil.toDict(policy)
